@@ -273,15 +273,10 @@ static void tfbm_pan_display(int fh, struct fb_var_screeninfo *var)
 #if defined(JFB_ENABLE_DIMMER) && defined(FBIOBLANK)
 int tfbm_set_blank(int fh, int blank)
 {
-      int fd;
       struct vt_stat vstat;
-      if (-1 == (fd = util_privilege_open("/dev/tty0", O_RDWR, 0))) {
-              die("open /dev/tty0: %s\n", strerror(errno));
-      }
-      if (-1 == ioctl(fd, VT_GETSTATE, &vstat)) {
+      if (-1 == ioctl(gFramebuffer.ttyfd, VT_GETSTATE, &vstat)) {
               die("ioctl VT_GETSTATE");
       }
-      close(fd);
       if (vstat.v_active != gFramebuffer.my_vt)
               return(0);         /* Not foreground console */
 
@@ -459,15 +454,14 @@ void tfbm_init(TFrameBufferMemory* p)
 		struct fb_con2fbmap c2m;
 		struct vt_stat vstat;
 
-		if (-1 == (fd = util_privilege_open("/dev/tty0", O_RDWR))) {
+		if (-1 == (p->ttyfd = util_privilege_open("/dev/tty0", O_RDWR))) {
 			util_free(fbdn);
 			die("open /dev/tty0: %s\n", strerror(errno));
 		}
-		if (-1 == ioctl(fd, VT_GETSTATE, &vstat)) {
+		if (-1 == ioctl(p->ttyfd, VT_GETSTATE, &vstat)) {
 			util_free(fbdn);
 			die("ioctl VT_GETSTATE");
 		}
-		close(fd);
 #ifdef JFB_ENABLE_DIMMER
 		p->my_vt = c2m.console = vstat.v_active;
 #else
