@@ -30,8 +30,8 @@
 #include <endian.h>
 #include <linux/fb.h>
 
-#include <fbdpsp.h>
-#include <fbcommon.h>
+#include "fbdpsp.h"
+#include "fbcommon.h"
 
 #ifndef min
 #  define min(a, b)   (((a)>(b))?(b):(a))
