@@ -29,6 +29,8 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <sys/types.h>
+#include <sys/stat.h>
+#include <fcntl.h>
 #include <string.h>
 #include <unistd.h>
 
@@ -387,49 +389,66 @@ const u_char* tfont_standard_glyph(
 	}
 }
 
-static void tfont_setup_font(TFont* pf, const char* fname, FONTSET_HALF hf)
+static FILE *font_open(const char *fname)
 {
-	char cmd[1024];
-	FILE* fp;
-	TPcf pcf;
-	int piped;
 	int nf = strlen(fname);
 
+	if ((nf > 3 && strcmp(".gz", fname+nf-3) == 0) ||
+	    (nf > 2 && strcmp(".Z", fname+nf-2) == 0)) {
+		pid_t pid;
+		int filedes[2];
+		if (pipe(filedes) < 0) {
+			return NULL;
+		}
+		pid = fork();
+		if (pid == -1) {
+			goto err;
+		} else if (pid == 0) {
+			/* child */
+			int fd0 = open(fname, O_RDONLY);
+			if (fd0 < 0) {
+				goto err;
+			}
+			close(filedes[0]);
+			close(0); close(1);
+			dup2(fd0, 0);
+			dup2(filedes[1], 1);
+#ifndef JFB_GZIP_PATH
+#error			JFB_GZIP_PATH is not set.
+#else
+			execl(JFB_GZIP_PATH, JFB_GZIP_PATH, "-dc", NULL);
+#endif
+			exit(0);
+		}
+		close(filedes[1]);
+		return fdopen(filedes[0], "r");
+err:
+		close(filedes[0]);
+		close(filedes[1]);
+		return NULL;
+	} else {
+		return fopen(fname, "r");
+	}
+	return NULL;
+}
+
+static void tfont_setup_font(TFont* pf, const char* fname, FONTSET_HALF hf)
+{
+	FILE* fp;
+	TPcf pcf;
 	tpcf_init(&pcf);
 
 	if (access(fname, R_OK) != 0) {
 		print_message("PCF : CANNOTOPEN : %s\n", fname);
 		return;
 	}
-	if ((nf > 3 && strcmp(".gz", fname+nf-3) == 0) ||
-	    (nf > 2 && strcmp(".Z", fname+nf-2) == 0)) {
-		if (strlen(JFB_GZIP_PATH) + 10 + nf >= sizeof cmd) {
-			print_message("PCF : long filename? : %s\n", fname);
-			return;
-		}
-#ifndef JFB_GZIP_PATH
-#error		JFB_GZIP_PATH is not set.
-#else
-		strcpy(cmd, JFB_GZIP_PATH " -c < \"");
-#endif
-		strcat(cmd, fname);
-		strcat(cmd, "\"");
-		fp = popen(cmd, "r");
-		piped = 1;
-	} else {
-		fp = fopen(fname, "r");
-		piped = 0;
-	}
+	fp = font_open(fname);
 	if (!fp) {
 		print_message("PCF : CANNOTOPEN : %s\n", fname);
 		return;
 	}
 	tpcf_load(&pcf, fp);
-	if (piped) {
-		pclose(fp);
-	} else {
-		fclose(fp);
-	}
+	fclose(fp);
 
 	tpcf_as_tfont(&pcf, pf);
 	pf->fhalf = hf;
