@@ -35,6 +35,7 @@
 #include	<string.h>
 #include	<sys/types.h>
 
+#include	"main.h"
 #include	"message.h"
 
 void die(const char *format, ...)
@@ -74,6 +75,8 @@ void print_message(const char *format, ...)
 {
 	va_list args;
 
+	if (gApp.gOptQuiet)
+	    return;
 	va_start(args, format);
 	vfprintf(stderr, format, args);
 	va_end(args);
